%bcond_without reconf

Name: pcre2
Version: 10.35
Release: 1
License: BSD-3-Clause
Summary: Perl-Compatible Regular Expression library
Url: http://www.pcre.org

Source0: ftp://ftp.pcre.org/pub/pcre/pcre2-%{version}.tar.gz

#Patch0: pcre-posix-compat.patch

BuildRequires: bzip2-devel
BuildRequires: zlib-devel
BuildRequires: readline-devel

%if %{with reconf}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: m4-gnu
BuildRequires: libtool
BuildRequires: gettext-tools
%endif


%description
PCRE2 is a re-working of the original PCRE (Perl-compatible regular
expression) library to provide an entirely new API.
 
PCRE2 is written in C, and it has its own API. This package provides support 
for strings in 8-bit and UTF-8 encodings.
 
The distribution does contain a set of C wrapper functions for the 8-bit
library that are based on the POSIX regular expression API (see the pcre2posix
man page). These can be found in a library called libpcre2posix. Note that
this just provides a POSIX calling interface to PCRE2; the regular expressions
themselves still follow Perl syntax and semantics. The POSIX API is
restricted, and does not give full access to all of PCRE2's facilities.

%package tools
Summary: pcre2 tools

%description tools
Provides the pcregrep and pcretest command line tools.


%package -n libpcre2-8-0
Summary: pcre2-8 library
Provides: pcre2-8 = %{version}-%{release}

%description -n libpcre2-8-0
Provides the libpcre2-8 library.


%package -n libpcre2-posix2
Summary: pcre2 library

%description -n libpcre2-posix2
Provides the libpcre2-posix library.


%package devel
Summary: pcre2 development files
Requires: libpcre2-8-0 = %{version}-%{release}
Requires: libpcre2-posix2 = %{version}-%{release}

%description devel
Provides the pcre2 development files.

%prep
%setup -q


%build

%if %{with reconf}
autoreconf -fi
%else
%define _host powerpc-ibm-aix7
%endif

%configure \
  LDFLAGS="-Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
  --with-aix-soname=svr4 \
  --disable-static \
  --enable-pcre2grep-libz \
  --enable-pcre2grep-libbz2 \
  --enable-pcre2test-libreadline \
  # end

%make_build


%install

%make_install

rm %{buildroot}/%{_libdir}/*.la

%files tools
%defattr(-, qsys, *none)
%{_bindir}/pcre2grep
%{_bindir}/pcre2test
%{_mandir}/man1/pcre2grep.1*
%{_mandir}/man1/pcre2test.1*


%files -n libpcre2-8-0
%defattr(-, qsys, *none)
%{_libdir}/libpcre2-8.so.0*
%{_docdir}/pcre2


%files -n libpcre2-posix2
%defattr(-, qsys, *none)
%{_libdir}/libpcre2-posix.so.2*


%files devel
%defattr(-, qsys, *none)
%license COPYING LICENCE
%doc NEWS README

%{_bindir}/pcre2-config
%{_mandir}/man1/pcre2-config.1*

%{_includedir}/pcre2.h
%{_includedir}/pcre2posix.h

%{_libdir}/libpcre2-8.so
%{_libdir}/libpcre2-posix.so

%{_libdir}/pkgconfig/libpcre2-8.pc
%{_libdir}/pkgconfig/libpcre2-posix.pc

%{_mandir}/man3/pcre2.3*
%{_mandir}/man3/pcre2_callout_enumerate.3*
%{_mandir}/man3/pcre2_code_copy.3*
%{_mandir}/man3/pcre2_code_copy_with_tables.3*
%{_mandir}/man3/pcre2_code_free.3*
%{_mandir}/man3/pcre2_compile.3*
%{_mandir}/man3/pcre2_compile_context_copy.3*
%{_mandir}/man3/pcre2_compile_context_create.3*
%{_mandir}/man3/pcre2_compile_context_free.3*
%{_mandir}/man3/pcre2_config.3*
%{_mandir}/man3/pcre2_convert_context_copy.3*
%{_mandir}/man3/pcre2_convert_context_create.3*
%{_mandir}/man3/pcre2_convert_context_free.3*
%{_mandir}/man3/pcre2_converted_pattern_free.3*
%{_mandir}/man3/pcre2_dfa_match.3*
%{_mandir}/man3/pcre2_general_context_copy.3*
%{_mandir}/man3/pcre2_general_context_create.3*
%{_mandir}/man3/pcre2_general_context_free.3*
%{_mandir}/man3/pcre2_get_error_message.3*
%{_mandir}/man3/pcre2_get_mark.3*
%{_mandir}/man3/pcre2_get_match_data_size.3*
%{_mandir}/man3/pcre2_get_ovector_count.3*
%{_mandir}/man3/pcre2_get_ovector_pointer.3*
%{_mandir}/man3/pcre2_get_startchar.3*
%{_mandir}/man3/pcre2_jit_compile.3*
%{_mandir}/man3/pcre2_jit_free_unused_memory.3*
%{_mandir}/man3/pcre2_jit_match.3*
%{_mandir}/man3/pcre2_jit_stack_assign.3*
%{_mandir}/man3/pcre2_jit_stack_create.3*
%{_mandir}/man3/pcre2_jit_stack_free.3*
%{_mandir}/man3/pcre2_maketables.3*
%{_mandir}/man3/pcre2_maketables_free.3*
%{_mandir}/man3/pcre2_match.3*
%{_mandir}/man3/pcre2_match_context_copy.3*
%{_mandir}/man3/pcre2_match_context_create.3*
%{_mandir}/man3/pcre2_match_context_free.3*
%{_mandir}/man3/pcre2_match_data_create.3*
%{_mandir}/man3/pcre2_match_data_create_from_pattern.3*
%{_mandir}/man3/pcre2_match_data_free.3*
%{_mandir}/man3/pcre2_pattern_convert.3*
%{_mandir}/man3/pcre2_pattern_info.3*
%{_mandir}/man3/pcre2_serialize_decode.3*
%{_mandir}/man3/pcre2_serialize_encode.3*
%{_mandir}/man3/pcre2_serialize_free.3*
%{_mandir}/man3/pcre2_serialize_get_number_of_codes.3*
%{_mandir}/man3/pcre2_set_bsr.3*
%{_mandir}/man3/pcre2_set_callout.3*
%{_mandir}/man3/pcre2_set_character_tables.3*
%{_mandir}/man3/pcre2_set_compile_extra_options.3*
%{_mandir}/man3/pcre2_set_compile_recursion_guard.3*
%{_mandir}/man3/pcre2_set_depth_limit.3*
%{_mandir}/man3/pcre2_set_glob_escape.3*
%{_mandir}/man3/pcre2_set_glob_separator.3*
%{_mandir}/man3/pcre2_set_heap_limit.3*
%{_mandir}/man3/pcre2_set_match_limit.3*
%{_mandir}/man3/pcre2_set_max_pattern_length.3*
%{_mandir}/man3/pcre2_set_newline.3*
%{_mandir}/man3/pcre2_set_offset_limit.3*
%{_mandir}/man3/pcre2_set_parens_nest_limit.3*
%{_mandir}/man3/pcre2_set_recursion_limit.3*
%{_mandir}/man3/pcre2_set_recursion_memory_management.3*
%{_mandir}/man3/pcre2_set_substitute_callout.3*
%{_mandir}/man3/pcre2_substitute.3*
%{_mandir}/man3/pcre2_substring_copy_byname.3*
%{_mandir}/man3/pcre2_substring_copy_bynumber.3*
%{_mandir}/man3/pcre2_substring_free.3*
%{_mandir}/man3/pcre2_substring_get_byname.3*
%{_mandir}/man3/pcre2_substring_get_bynumber.3*
%{_mandir}/man3/pcre2_substring_length_byname.3*
%{_mandir}/man3/pcre2_substring_length_bynumber.3*
%{_mandir}/man3/pcre2_substring_list_free.3*
%{_mandir}/man3/pcre2_substring_list_get.3*
%{_mandir}/man3/pcre2_substring_nametable_scan.3*
%{_mandir}/man3/pcre2_substring_number_from_name.3*

%{_mandir}/man3/pcre2api.3*
%{_mandir}/man3/pcre2build.3*
%{_mandir}/man3/pcre2callout.3*
%{_mandir}/man3/pcre2compat.3*
%{_mandir}/man3/pcre2convert.3*
%{_mandir}/man3/pcre2demo.3*
%{_mandir}/man3/pcre2jit.3*
%{_mandir}/man3/pcre2limits.3*
%{_mandir}/man3/pcre2matching.3*
%{_mandir}/man3/pcre2partial.3*
%{_mandir}/man3/pcre2pattern.3*
%{_mandir}/man3/pcre2perform.3*
%{_mandir}/man3/pcre2posix.3*
%{_mandir}/man3/pcre2sample.3*
%{_mandir}/man3/pcre2serialize.3*
%{_mandir}/man3/pcre2syntax.3*
%{_mandir}/man3/pcre2unicode.3*

%changelog
* Fri Aug 28 2020 Eric Simpson <esimpson@ca.ibm.com> - 10.35
- Initial build for IBM i
